==> mayako_core-0.1.4-py3-none-any.whl: mayako/GUI/Controllers/MainController.py <==
from ..Views.MainView import MainView
from .AddDeviceController import AddDeviceController
from .EditDeviceController import EditDeviceController
from .AddWiFiProfileController import AddWiFiProfileController
from .EditWiFiProfileController import EditWiFiProfileController
from .DownloadArduinoController import DownloadArduinoController
from .HomeController import HomeController
from ...MayakoData import MayakoData
from ...Client import Client

class MainController:

    def __init__(self, main_view: MainView, model: MayakoData, client: Client) -> None:
        self.model = model
        self.main_view = main_view
        self.client = client
        self.home_controller = HomeController(self.main_view, self.model, self.client)
        self.add_device_controller = AddDeviceController(self.main_view, self.model, self.client)
        self.add_wifi_profile_controller = AddWiFiProfileController(self.main_view, self.model, self.client)
        self.edit_wifi_profile_controller = EditWiFiProfileController(self.main_view, self.model, self.client)
        self.edit_device_controller = EditDeviceController(self.main_view, self.model, self.client)
        self.download_arduino_controller = DownloadArduinoController(self.main_view, self.model, self.client)

        #set observable method on model class (central point of mayako)
    
    #define callback functions that are on the model classes

    def start(self) -> None:
        self.main_view.switch("home")
        self.main_view.start_mainloop()

==> mayako_core-0.1.5-py3-none-any.whl: mayako/GUI/Controllers/MainController.py <==
from ..Views.MainView import MainView
from .AddDeviceController import AddDeviceController
from .DeviceDetailsController import DeviceDetailsController
from .AddWiFiProfileController import AddWiFiProfileController
from .EditWiFiProfileController import EditWiFiProfileController
from .DownloadArduinoController import DownloadArduinoController
from .HomeController import HomeController
from ...MayakoData import MayakoData
from ...Client import Client

class MainController:

    def __init__(self, main_view: MainView, model: MayakoData, client: Client) -> None:
        self.model = model
        self.main_view = main_view
        self.client = client
        self.home_controller = HomeController(self.main_view, self.model, self.client)
        self.add_device_controller = AddDeviceController(self.main_view, self.model, self.client)
        self.add_wifi_profile_controller = AddWiFiProfileController(self.main_view, self.model, self.client)
        self.edit_wifi_profile_controller = EditWiFiProfileController(self.main_view, self.model, self.client)
        self.device_deails_controller = DeviceDetailsController(self.main_view, self.model, self.client)
        self.download_arduino_controller = DownloadArduinoController(self.main_view, self.model, self.client)

        #set observable method on model class (central point of mayako)
    
    #define callback functions that are on the model classes

    def start(self) -> None:
        self.main_view.switch("home")
        self.main_view.start_mainloop()
